Index: app.c
===================================================================
RCS file: /devel/neoipbx/asterisk/asterisk/app.c,v
retrieving revision 1.5
diff -u -r1.5 app.c
--- app.c	26 Jan 2005 11:04:20 -0000	1.5
+++ app.c	15 Feb 2005 10:57:34 -0000
@@ -37,11 +37,20 @@
 #define MAX_OTHER_FORMATS 10
 
 
+/* 
+This function presents a dialtone and reads an extension into 'collect' 
+which must be a pointer to a **pre-initilized** array of char having a 
+size of 'size' suitable for writing to.  It will collect no more than the smaller 
+of 'maxlen' or 'size' minus the original strlen() of collect digits.
+*/
 int ast_app_dtget(struct ast_channel *chan, const char *context, char *collect, size_t size, int maxlen, int timeout) 
 {
 	struct tone_zone_sound *ts;
 	int res=0, x=0;
 
+	if(maxlen > size)
+		maxlen = size;
+	
 	if(!timeout && chan->pbx)
 		timeout = chan->pbx->dtimeout;
 	else if(!timeout)
@@ -53,8 +62,7 @@
 	} else 
 		ast_log(LOG_NOTICE,"Huh....? no dial for indications?\n");
 	
-	memset(collect, 0, size);
-	for (x=0; strlen(collect) < size; ) {
+	for (x = strlen(collect); strlen(collect) < maxlen; ) {
 		res = ast_waitfordigit(chan, timeout);
 		if (!ast_ignore_pattern(context, collect))
 			ast_playtones_stop(chan);
Index: res/res_features.c
===================================================================
RCS file: /devel/neoipbx/asterisk/asterisk/res/res_features.c,v
retrieving revision 1.8
diff -u -r1.8 res_features.c
--- res/res_features.c	14 Feb 2005 14:17:54 -0000	1.8
+++ res/res_features.c	15 Feb 2005 10:57:34 -0000
@@ -458,9 +458,8 @@
 	struct ast_channel *transferer;
 	struct ast_channel *transferee;
 	char *transferer_real_context;
-	char newext[256], *ptr;
+	char newext[256];
 	int res;
-	int len;
 
 	if (sense == FEATURE_SENSE_PEER) {
 		transferer = peer;
@@ -484,8 +483,7 @@
 	ast_moh_start(transferee, NULL);
 
 	memset(newext, 0, sizeof(newext));
-	ptr = newext;
-
+	
 	/* Transfer */
 	if ((res=ast_streamfile(transferer, "pbx-transfer", transferer->language))) {
 		ast_moh_stop(transferee);
@@ -498,15 +496,12 @@
 		ast_autoservice_stop(transferee);
 		ast_indicate(transferee, AST_CONTROL_UNHOLD);
 		return res;
-	}
-	ast_stopstream(transferer);
-	if (res > 0) {
+	} else if (res > 0) {
 		/* If they've typed a digit already, handle it */
-		newext[0] = res;
-		ptr++;
-		len--;
+		newext[0] = (char) res;
 	}
 
+	ast_stopstream(transferer);
 	res = ast_app_dtget(transferer, transferer_real_context, newext, sizeof(newext), 100, transferdigittimeout);
 	if (res < 0) {
 		ast_moh_stop(transferee);
@@ -619,7 +614,7 @@
 	ast_indicate(transferee, AST_CONTROL_HOLD);
 	ast_autoservice_start(transferee);
 	ast_moh_start(transferee, NULL);
-
+	memset(xferto, 0, sizeof(xferto));
 	/* Transfer */
 	if ((res=ast_streamfile(transferer, "pbx-transfer", transferer->language))) {
 		ast_moh_stop(transferee);
@@ -632,6 +627,9 @@
 		ast_autoservice_stop(transferee);
 		ast_indicate(transferee, AST_CONTROL_UNHOLD);
 		return res;
+	} else if(res > 0) {
+		/* If they've typed a digit already, handle it */
+		xferto[0] = (char) res;
 	}
 	if ((ast_app_dtget(transferer, transferer_real_context, xferto, sizeof(xferto), 100, transferdigittimeout))) {
 		cid_num = transferer->cid.cid_num;
